﻿using System;
using System.ComponentModel;
using System.Web.UI;

namespace TestProject.NoticeBoard.Controls
{
    /// <summary>
    /// 페이징 컨트롤
    /// </summary>
    public partial class PagingControl : UserControl
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 레코드 수
        /// </summary>
        private int recordCount;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 검색 모드 - SearchMode

        /// <summary>
        /// 검색 모드
        /// </summary>
        public bool SearchMode { get; set; } = false;

        #endregion
        #region 검색 필드 - SearchField

        /// <summary>
        /// 검색 필드
        /// </summary>
        public string SearchField { get; set; }

        #endregion
        #region 검색 쿼리 - SearchQuery

        /// <summary>
        /// 검색 쿼리
        /// </summary>
        public string SearchQuery { get; set; }

        #endregion
        #region 페이지 인덱스 - PageIndex

        /// <summary>
        /// 페이지 인덱스
        /// </summary>
        [Category("PagingControl")]
        public int PageIndex { get; set; }

        #endregion
        #region 페이지 수 - PageCount

        /// <summary>
        /// 페이지 수
        /// </summary>
        [Category("PagingControl")]
        public int PageCount { get; set; }

        #endregion
        #region 페이지 크기 - PageSize

        /// <summary>
        /// 페이지 크기
        /// </summary>
        [Category("PagingControl")]
        public int PageSize { get; set; } = 10;

        #endregion
        #region 레코드 수 - RecordCount

        /// <summary>
        /// 레코드 수
        /// </summary>
        [Category("PagingControl")]
        public int RecordCount
        {
            get
            {
                return this.recordCount;
            }
            set
            {
                this.recordCount = value;

                PageCount = ((this.recordCount - 1) / PageSize) + 1;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 페이지 로드시 처리하기 - Page_Load(sender, e)

        /// <summary>
        /// 페이지 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            SearchMode = (!string.IsNullOrEmpty(Request.QueryString["SearchField"]) && !string.IsNullOrEmpty(Request.QueryString["SearchQuery"]));

            if(SearchMode)
            {
                SearchField = Request.QueryString["SearchField"];
                SearchQuery = Request.QueryString["SearchQuery"];
            }

            PageIndex++;

            int i;

            string html = "<ul class='pagination pagination-sm'>";

            if(PageIndex > 10)
            {
                if(SearchMode)
                {
                    html += "<li><a href=\""                                   +
                            Request.ServerVariables["SCRIPT_NAME"]             +
                            "?Page="                                           +
                            Convert.ToString(((PageIndex - 1) / (int)10) * 10) +
                            "&SearchField="                                    +
                            SearchField                                        +
                            "&SearchQuery="                                    +
                            SearchQuery                                        +
                            "\">◀</a></li>";
                }
                else
                {
                    html += "<li><a href=\""                                   +
                            Request.ServerVariables["SCRIPT_NAME"]             +
                            "?Page="                                           +
                            Convert.ToString(((PageIndex - 1) / (int)10) * 10) +
                            "\">◀</a></li>";
                }
            }
            else
            {
                html += "<li class=\"disabled\"><a>◁</a></li>";
            }

            for(i = (((PageIndex - 1) / (int)10) * 10 + 1); i <= ((((PageIndex - 1) / (int)10) + 1) * 10); i++)
            {
                if(i > PageCount)
                {
                    break;
                }

                if(i == PageIndex)
                {
                    html += " <li class='active'><a href='#'>" + i.ToString() + "</a></li>";
                }
                else
                {
                    if(SearchMode)
                    {
                        html += "<li><a href=\""                       +
                                Request.ServerVariables["SCRIPT_NAME"] +
                                "?Page="                               +
                                i.ToString()                           +
                                "&SearchField="                        +
                                SearchField                            +
                                "&SearchQuery="                        +
                                SearchQuery                            +
                                "\">"                                  +
                                i.ToString()                           +
                                "</a></li>";
                    }
                    else
                    {
                        html += "<li><a href=\""                       +
                                Request.ServerVariables["SCRIPT_NAME"] +
                                "?Page="                               +
                                i.ToString()                           +
                                "\">"                                  +
                                i.ToString()                           +
                                "</a></li>";
                    }
                }
            }

            if(i < PageCount)
            {
                if(SearchMode)
                {
                    html += "<li><a href=\""                                        +
                            Request.ServerVariables["SCRIPT_NAME"]                  +
                            "?Page="                                                +
                            Convert.ToString(((PageIndex - 1) / (int)10) * 10 + 11) +
                            "&SearchField="                                         +
                            SearchField                                             +
                            "&SearchQuery="                                         +
                            SearchQuery                                             +
                            "\">▶</a></li>";
                }
                else
                {
                    html += "<li><a href=\""                                        +
                            Request.ServerVariables["SCRIPT_NAME"]                  +
                            "?Page="                                                +
                            Convert.ToString(((PageIndex - 1) / (int)10) * 10 + 11) +
                            "\">▶</a></li>";
                }
            }
            else
            {
                html += "<li class=\"disabled\"><a>▷</a></li>";
            }

            html += "</ul>";

            this.pagingLiteral.Text = html;
        }

        #endregion
    }
}