﻿using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.Linq;

using Dapper;

namespace NoticeBoard.Models
{
    /// <summary>
    /// 댓글 저장소
    /// </summary>
    public class CommentRepository
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// SQL 연결
        /// </summary>
        private SqlConnection connection;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - CommentRepository()

        /// <summary>
        /// 생성자
        /// </summary>
        public CommentRepository()
        {
            this.connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 댓글 추가하기 - AddComment(comment)

        /// <summary>
        /// 댓글 추가하기
        /// </summary>
        /// <param name="comment">댓글</param>
        public void AddComment(CommentModel comment)
        {
            DynamicParameters parameters = new DynamicParameters();

            parameters.Add("@NoticeID", value : comment.NoticeID, dbType: DbType.Int32 );
            parameters.Add("@Name"    , value : comment.Name    , dbType: DbType.String);
            parameters.Add("@Comment" , value : comment.Comment , dbType: DbType.String);
            parameters.Add("@Password", value : comment.Password, dbType: DbType.String);

            string sql = @"
INSERT INTO dbo.NoticeComment
(
    NoticeID
   ,[Name]
   ,Comment
   ,[Password]
)
VALUES
(
    @NoticeID
   ,@Name
   ,@Comment
   ,@Password
);

UPDATE dbo.Notice
SET    CommentCount = CommentCount + 1
WHERE  ID = @NoticeID
";

            this.connection.Execute(sql, parameters, commandType : CommandType.Text);
        }

        #endregion
        #region 댓글 리스트 구하기 - GetCommentList(noticeID)

        /// <summary>
        /// 댓글 리스트 구하기
        /// </summary>
        /// <param name="noticeID">게시판 ID</param>
        /// <returns>댓글 리스트</returns>
        public List<CommentModel> GetCommentList(int noticeID)
        {
            return this.connection.Query<CommentModel>
            (
                "SELECT * FROM dbo.NoticeComment WHERE NoticeID = @NoticeID",
                new { NoticeID = noticeID },
                commandType : CommandType.Text
            ).ToList();
        }

        #endregion
        #region 댓글 수 구하기 - GetCommentCount(noticeID, id, password)

        /// <summary>
        /// 댓글 수 구하기
        /// </summary>
        /// <param name="noticeID">게시판 ID</param>
        /// <param name="id">id</param>
        /// <param name="password">패스워드</param>
        /// <returns>댓글 수</returns>
        public int GetCommentCount(int noticeID, int id, string password)
        {
            return this.connection.Query<int>
            (
                @"
SELECT COUNT(*)
FROM   dbo.NoticeComment
WHERE  NoticeID   = @NoticeID
AND    ID         = @ID
AND    [Password] = @Password",
                new { NoticeID = noticeID, ID = id, Password = password },
                commandType : CommandType.Text
            ).SingleOrDefault();
        }

        #endregion
        #region 댓글 삭제하기 - DeleteComment(noticeID, id, password)

        /// <summary>
        /// 댓글 삭제하기
        /// </summary>
        /// <param name="noticeID">게시판 ID</param>
        /// <param name="id">ID</param>
        /// <param name="password">패스워드</param>
        /// <returns>처리 행 수</returns>
        public int DeleteComment(int noticeID, int id, string password)
        {
            return this.connection.Execute
            (
                @"
DELETE FROM dbo.NoticeComment
WHERE  NoticeID   = @NoticeID
AND    ID         = @ID
AND    [Password] = @Password;

UPDATE dbo.Notice
SET    CommentCount = CommentCount - 1
WHERE  ID = @NoticeID",
                new { NoticeID = noticeID, ID = id, Password = password },
                commandType : CommandType.Text
            );
        }

        #endregion
        #region 최근 댓글 리스트 구하기 - GetRecentCommentList()

        /// <summary>
        /// 최근 댓글 리스트 구하기
        /// </summary>
        public List<CommentModel> GetRecentCommentList()
        {
            string sql = @"
SELECT TOP 3
    ID
   ,NoticeID
   ,Comment
   ,WriteDate
FROM dbo.NoticeComment
ORDER BY ID DESC";

            return this.connection.Query<CommentModel>(sql).ToList();
        }

        #endregion
    }
}