﻿using System;
using System.Web.UI;

using NoticeBoard.Models;

namespace TestProject.NoticeBoard
{
    /// <summary>
    /// 게시판 목록 페이지
    /// </summary>
    public partial class NoticeListPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region Field

        /// <summary>
        /// 페이지 인덱스
        /// </summary>
        public int PageIndex = 0;

        /// <summary>
        /// 레코드 카운트
        /// </summary>
        public int RecordCount = 0;

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 게시글 저장소
        /// </summary>
        private NoticeRepository repository;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 검색 모드 여부 - SearchMode

        /// <summary>
        /// 검색 모드 여부
        /// </summary>
        public bool SearchMode { get; set; } = false;

        #endregion
        #region 검색 필드 - SearchField

        /// <summary>
        /// 검색 필드
        /// </summary>
        public string SearchField { get; set; }

        #endregion
        #region 검색 쿼리 - SearchQuery

        /// <summary>
        /// 검색 쿼리
        /// </summary>
        public string SearchQuery { get; set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - NoticeListPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public NoticeListPage()
        {
            this.repository = new NoticeRepository();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 페이지 로드시 처리하기 - Page_Load(sender, e)

        /// <summary>
        /// 페이지 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            SearchMode = (!string.IsNullOrEmpty(Request.QueryString["SearchField"]) && !string.IsNullOrEmpty(Request.QueryString["SearchQuery"]));

            if(SearchMode)
            {
                SearchField = Request.QueryString["SearchField"];
                SearchQuery = Request.QueryString["SearchQuery"];
            }

            if(Request["Page"] != null)
            {
                PageIndex = Convert.ToInt32(Request["Page"]) - 1;
            }
            else
            {
                PageIndex = 0;
            }

            if(SearchMode == false)
            {
                RecordCount = this.repository.GetCount();
            }
            else
            {
                RecordCount = this.repository.GetCount(SearchField, SearchQuery);
            }

            this.totalRecordLabel.Text = RecordCount.ToString();

            this.pagingControl.PageIndex   = PageIndex;
            this.pagingControl.RecordCount = RecordCount;

            if(!Page.IsPostBack)
            {
                DisplayData();
            }
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 데이터 표시하기 - DisplayData()

        /// <summary>
        /// 데이터 표시하기
        /// </summary>
        private void DisplayData()
        {
            if(SearchMode == false)
            {
                this.gridView.DataSource = this.repository.GetList(PageIndex);
            }
            else
            {
                this.gridView.DataSource = this.repository.Search(PageIndex, SearchField, SearchQuery);
            }

            this.gridView.DataBind();
        }

        #endregion
    }
}