﻿using System;
using System.Web.UI;

using NoticeBoard.Models;

namespace TestProject.NoticeBoard
{
    /// <summary>
    /// 게시글 보기 페이지
    /// </summary>
    public partial class NoticeViewPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// ID
        /// </summary>
        private string id;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 페이지 로드시 처리하기 - Page_Load(sender, e)

        /// <summary>
        /// 페이지 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            this.deleteHyperLink.NavigateUrl = "NoticeDeletePage.aspx?ID=" + Request["ID"];
            this.updateHyperLink.NavigateUrl = "NoticeUpdatePage.aspx?ID=" + Request["ID"];
            this.replyHyperLink.NavigateUrl  = "NoticeReplyPage.aspx?ID="  + Request["ID"];

            this.id = Request.QueryString["ID"];

            if(this.id == null)
            {
                Response.Redirect("./NoticeListPage.aspx");
            }

            if(!Page.IsPostBack)
            {
                DisplayData();
            }
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 데이터 표시하기 - DisplayData()

        /// <summary>
        /// 데이터 표시하기
        /// </summary>
        private void DisplayData()
        {
            NoticeModel notice = (new NoticeRepository()).Get(Convert.ToInt32(this.id));

            this.idLabel.Text          = this.id;
            this.nameLabel.Text        = notice.Name;
            this.mailAddressLabel.Text = string.Format("<a href=\"mailto:{0}\">{0}</a>", notice.MailAddress);
            this.titleLabel.Text       = notice.Title;

            string content = notice.Content;

            string encoding = notice.Encoding;

            if(encoding == "Text")
            {
                this.contentLabel.Text = HTMLHelper.EncodeIncludingTabAndSpace(content);
            }
            else if(encoding == "Mixed")
            {
                this.contentLabel.Text = content.Replace("\r\n", "<br />");
            }
            else
            {
                this.contentLabel.Text = content;
            }

            this.readCountLabel.Text = notice.ReadCount.ToString();
            this.homepageLabel.Text  = string.Format("<a href=\"{0}\" target=\"_blank\">{0}</a>", notice.Homepage);
            this.writeDateLabel.Text = notice.WriteDate.ToString();
            this.writeIPLabel.Text   = notice.WriteIP;

            if(notice.FileName.Length > 1)
            {
                this.fileLabel.Text = string.Format
                (
                    "<a href='./NoticeDownloadPage.aspx?ID={0}'>{1} {2} / 전송 수 : {3}</a>",
                    notice.ID,
                    "<img src=\"/images/ext/ext_zip.gif\" border=\"0\">",
                    notice.FileName,
                    notice.DownloadCount
                );

                if(NoticeBoardHelper.IsImageFile(notice.FileName))
                {
                    this.imageLiteral.Text = $"<img src=\'ImageDownloadPage.aspx?FileName={Server.UrlEncode(notice.FileName)}\'>";
                }
            }
            else
            {
                this.fileLabel.Text = "(업로드된 파일이 없습니다.)";
            }
        }

        #endregion
    }
}